@@ -1,7 +1,7 @@
 """
 Type annotations for appsync service literal definitions.
 
-[Open documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_appsync/literals/)
+[Open documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_appsync/literals.html)
 
 Usage::
 
@@ -42,11 +42,8 @@ __all__ = (
     "ResolverKindType",
     "SchemaStatusType",
     "TypeDefinitionFormatType",
-    "AppSyncServiceName",
     "ServiceName",
-    "ResourceServiceName",
     "PaginatorName",
-    "RegionName",
 )
 
 
@@ -100,7 +97,6 @@ SchemaStatusType = Literal[
     "ACTIVE", "DELETING", "FAILED", "NOT_APPLICABLE", "PROCESSING", "SUCCESS"
 ]
 TypeDefinitionFormatType = Literal["JSON", "SDL"]
-AppSyncServiceName = Literal["appsync"]
 ServiceName = Literal[
     "accessanalyzer",
     "account",
@@ -389,18 +385,6 @@ ServiceName = Literal[
     "workspaces",
     "xray",
 ]
-ResourceServiceName = Literal[
-    "cloudformation",
-    "cloudwatch",
-    "dynamodb",
-    "ec2",
-    "glacier",
-    "iam",
-    "opsworks",
-    "s3",
-    "sns",
-    "sqs",
-]
 PaginatorName = Literal[
     "list_api_keys",
     "list_data_sources",
@@ -410,25 +394,3 @@ PaginatorName = Literal[
     "list_resolvers_by_function",
     "list_types",
 ]
-RegionName = Literal[
-    "ap-east-1",
-    "ap-northeast-1",
-    "ap-northeast-2",
-    "ap-northeast-3",
-    "ap-south-1",
-    "ap-southeast-1",
-    "ap-southeast-2",
-    "ca-central-1",
-    "eu-central-1",
-    "eu-north-1",
-    "eu-south-1",
-    "eu-west-1",
-    "eu-west-2",
-    "eu-west-3",
-    "me-south-1",
-    "sa-east-1",
-    "us-east-1",
-    "us-east-2",
-    "us-west-1",
-    "us-west-2",
-]
